from rest_framework.permissions import BasePermission

#--------------
# DJANGO REST PERMS
#--------------

class PermafrostRESTPermission(BasePermission):

    def has_permission(self, request, view):
        perms = getattr(view, "permission_required", set() )
        method_perms = getattr(view, "permission_required_" + request.method.lower(), set() )

        check_list = list(perms) + list(method_perms)
        user_perms = list(request.user.get_all_permissions())

        # Get the user's perms and check that all the itms in the list are present
        for perm in check_list:
            if perm not in user_perms:
                return False

        return True




from django.contrib.auth import get_user_model
from django.contrib.auth.models import Permission
from django.contrib.auth.backends import ModelBackend, AllowAllUsersModelBackend, RemoteUserBackend, AllowAllUsersRemoteUserBackend


class GroupSiteFilterMixin():

    def _get_group_permissions(self, user_obj):
        '''
        Adds the SiteID for filtering Groups
        '''
        user_groups_field = get_user_model()._meta.get_field('groups')
        user_groups_query = 'group__%s' % user_groups_field.related_query_name()
        return Permission.objects.filter(**{user_groups_query: user_obj})                   # TODO: Should it return Groups that do not have a Permafrost Role also?


class PermafrostModelBackend(GroupSiteFilterMixin, ModelBackend):
    '''
    Permafrost ModelBackend that takes into account SiteID when filtering on
    Group permissions via Permafrost Roles.
    '''
    pass
    # def _get_group_permissions(self, user_obj):
    #     return super()._get_group_permissions(user_obj).filter(group__permafrost_role__site=current_site)       # filter out groups in permaforstroles within the current site
        
        
    # def get_group_permissions(self, user_obj, obj=None):
    #     """
    #     Return a set of permission strings the user `user_obj` has from the
    #     groups they belong.
    #     """
    #     return self._get_permissions(user_obj, obj, 'group')


class PermafrostAllowAllUsersModelBackend(GroupSiteFilterMixin, AllowAllUsersModelBackend):
    '''
    Permafrost AllowAllUsersModelBackend that takes into account SiteID when filtering on
    Group permissions via Permafrost Roles.
    '''
    pass


class PermafrostRemoteUserBackend(GroupSiteFilterMixin, RemoteUserBackend):
    '''
    Permafrost RemoteUserBackend that takes into account SiteID when filtering on
    Group permissions via Permafrost Roles.
    '''
    pass


class PermafrostAllowAllUsersRemoteUserBackend(GroupSiteFilterMixin, AllowAllUsersRemoteUserBackend):
    '''
    Permafrost AllowAllUsersRemoteUserBackend that takes into account SiteID when filtering on
    Group permissions via Permafrost Roles.
    '''
    pass



#--------------------------------------------
# Copyright 2013-2019, Grant Viklund
# @Author: Grant Viklund
# @Date:   2017-02-20 13:50:51
# @Last Modified by:   Grant Viklund
# @Last Modified time: 2019-12-21 15:12:35
#--------------------------------------------

# https://timonweb.com/posts/how-to-get-a-list-of-all-user-permissions-available-in-django-based-project/

# import os
# import subprocess
# import json
# import fileinput

import pprint

from django.core.management.base import BaseCommand
from django.conf import settings
# from django.contrib.auth import get_user_model, get_backends
from django.contrib.auth.models import Permission
from permafrost.models import PermafrostCategory

class Command(BaseCommand):

    help = "Print out the exitsing PermafrostCategories in Python Dictionary format for migrating to the new code based format."
    debug = settings.DEBUG

    def handle(self, *args, **options):

        try:
            self.process_permission_list()

        except KeyboardInterrupt:
            print("\nExiting...")
            return

    def process_permission_list(self):
        categories = PermafrostCategory.objects.all()

        print("PermafrostCategory formatted for your code\n")

        data = {}

        for category in categories:            # Permission's Natural Key = codename + content_type.natural_key()      "{1}.{0}".format(*perm.natural_key())
            data[category.slug] = {
                "label": category.name,
                "level": category.level,
                "optional": [],
                "required": []
            }

            for item in category.permissions:
                app_lable, codename = item['perm'].split(".")
                perm = Permission.objects.get(codename=codename, content_type__app_label=app_lable )
                data[category.slug]["optional"].append( perm )

            for item in category.includes:
                app_lable, codename = item.split(".")
                perm = Permission.objects.get(codename=codename, content_type__app_label=app_lable )
                data[category.slug]["required"].append( perm )

        key_order = list(data.keys())
        key_order.sort()

        print("from django.utils.translation import ugettext_lazy as _\n")

        print("PERMAFROST_CATEGORIES = {")

        for key in key_order:
            print("    '{}': {{".format(key))
            print("        'label': _('{}'),".format(data[key]['label']))
            print("        'level': {},".format(data[key]['level']))

            if data[key]['optional']:
                print("        'optional': [")
                for item in data[key]['optional']:
                    print("            {{'label': _('{}'), 'permission': {} }},".format(item.name, item.natural_key()) )
                print("        ],")
            else:
                print("        'optional': [],")

            if data[key]['required']:
                print("        'required': [")
                for item in data[key]['required']:
                    print("            {{'label': _('{}'), 'permission': {} }},".format(item.name, item.natural_key()) )
                print("        ],")
            else:
                print("        'required': [],")

            print("    },")
        print("}\n")


'''
Sample Format:

PERMAFROST_CATEGORIES = {
    'user': {
        'label': _("User"),
        'access_level': 1,
        'optional': [
            {'label':_('Can Add Users to Role'), 'permission': ('add_user_to_role', 'permafrost', 'permafrostrole')},
        ],
        'required': [
            {'label':_('Can add Role'), 'permission': ('add_permafrostrole', 'permafrost', 'permafrostrole')},
        ],
    },
}

'''


# Generated by Django 3.0.3 on 2020-04-30 16:33

from django.db import migrations

def attach_group(apps, schema_editor):
    PermafrostRoleModel = apps.get_model('permafrost', 'PermafrostRole')
    GroupModel = apps.get_model('auth', 'Group')
    
    for row in PermafrostRoleModel.objects.all():
        group_name = "{0}_{1}_{2}".format( row.site.pk, row.category.slug, row.slug)
        row.group, created = GroupModel.objects.get_or_create(name=group_name) 
        row.save()

class Migration(migrations.Migration):

    dependencies = [
        ('permafrost', '0008_permafrostrole_group'),
    ]

    operations = [
        migrations.RunPython(attach_group, reverse_code=migrations.RunPython.noop),
    ]



import json

from django.test import TestCase 
from django.contrib.sites.models import Site
from django.contrib.auth import get_user_model
from django.db.utils import IntegrityError
from django.db import transaction
from django.contrib.auth.models import Group

from rest_framework.test import APIClient

from permafrost.models import PermafrostRole, PermafrostCategory, get_permission_models

class PermafrostCategoryModelTest(TestCase):

    fixtures = ['unit_test']

    def setUp(self):
        User = get_user_model()
        self.user = User.objects.create_user(username='john', email='jlennon@beatles.com', password='Passw0rd!')
        self.staffuser = User.objects.create_user(username='staffy', email='staffy@beatles.com', password='Passw0rd!')
        self.adminuser = User.objects.create_user(username='adminy', email='adminy@beatles.com', password='Passw0rd!')

        self.site_1 = Site.objects.get(pk=1)
        self.site_2 = Site.objects.get(pk=2)

        self.role_category_1 = PermafrostCategory.objects.get(pk=1)
        self.role_category_2 = PermafrostCategory.objects.get(pk=2)
        self.role_category_3 = PermafrostCategory.objects.get(pk=3)

    def test_natural_key(self):
        '''
        This is to really make sure the natural key does not chagnge.
        '''
        self.assertEqual( (self.role_category_1.slug,), self.role_category_1.natural_key())     # Make sure it's based on the slug

    def test_retrieve_by_natural_key(self):
        slug = self.role_category_1.slug
        cat = PermafrostCategory.objects.get_by_natural_key(slug=slug)
        self.assertEqual(self.role_category_1.pk, cat.pk)


class PermafrostRoleModelTest(TestCase):

    fixtures = ['unit_test']

    def setUp(self):
        User = get_user_model()
        self.user = User.objects.create_user(username='john', email='jlennon@beatles.com', password='Passw0rd!')
        self.staffuser = User.objects.create_user(username='staffy', email='staffy@beatles.com', password='Passw0rd!')
        self.adminuser = User.objects.create_user(username='adminy', email='adminy@beatles.com', password='Passw0rd!')

        self.site_1 = Site.objects.get(pk=1)
        self.site_2 = Site.objects.get(pk=2)

        self.role_category_1 = PermafrostCategory.objects.get(pk=1)
        self.role_category_2 = PermafrostCategory.objects.get(pk=2)
        self.role_category_3 = PermafrostCategory.objects.get(pk=3)

    #     self.client_user = get_user_model().objects.get(pk=5)
    #     self.client_staff = get_user_model().objects.get(pk=6)
    #     self.client_admin = get_user_model().objects.get(pk=7)

    def test_role_rename_updates_group(self):

        role = PermafrostRole(name="Awesome Students", category=self.role_category_1)
        role.save()

        pk_check = role.group.pk
        self.assertEqual(role.group.name, "1_user_awesome-students")

        role.name = "OK Students"
        role.save()

        new_role_group = Group.objects.get(name=role.get_group_name())

        self.assertEqual(role.group.name, "1_user_ok-students")
        self.assertEqual(role.group.pk, pk_check)                   # Make sure a new group was not generated
        
    def test_permission_objects_from_string(self):
        perms = get_permission_models("permafrost.view_permafrostrole")

        self.assertEqual(1, len(perms))

    def test_permission_objects_from_string_list(self):
        perms = get_permission_models( ["permafrost.view_permafrostrole", "permafrost.change_permafrostrole"] ) 

        self.assertEqual(2, len(perms))

    def test_create_user_role(self):
        # Test that creating a PermafrostRole creates a matching Group

        role = PermafrostRole(name="Bobs Super Group", category=self.role_category_1)
        role.save()

        self.assertEqual(role.group.name, "1_user_bobs-super-group")        # Checks that the user is created

        # Add the user to the PermafrostRole with the 
        role.users_add(self.user)

        # perms = [x.name for x in role.group.permissions.all()]
        # Get the list from the user?
        perms = list(self.user.get_all_permissions())

        # Test that "included" permissions are always present in the group
        self.assertEqual(perms, [])

    # def test_role_permission_limits(self):
        # Test that creating a PermafrostRole creates a matching Group

        # Test that permissions only in the Category's list can be added to the PermafrostRole

            # Get a list of the current permissions

            # try to add a permission

            # Check to see if it was added

    def test_create_staffuser_role(self):
        # Test that creating a PermafrostRole creates a matching Group

        role = PermafrostRole(name="Bobs Staff Group", category=self.role_category_2)
        role.save()

        self.assertEqual(role.group.name, "1_staff_bobs-staff-group")        # Checks that the user is created

        # Add user to the Group
        role.users_add(self.staffuser)
        perms = list(self.staffuser.get_all_permissions())
        perms.sort()

        check_list = ["permafrost.view_permafrostrole"]    # Needs to be sorted to try to make sure it's a close to the same as possible
        check_list.sort()

        # Test that "included" permissions are the only things present in the group
        self.assertEqual(perms, check_list)

    def test_only_allowed_category_perms_can_be_added(self):
        # Test that permissions not in the Category's list can not be added to the PermafrostRole
        pass

    def test_create_duplicate_role(self):
        # Test that creating a PermafrostRole of the same name producers and error
        role_a = PermafrostRole(name="Bobs Super Group", site=self.site_1, category=self.role_category_1)
        role_a.save()

        role_c = PermafrostRole(name="Bobs Super Group", site=self.site_2, category=self.role_category_1)
        role_c.save()

        with self.assertRaises(IntegrityError):

            with transaction.atomic():
                role_b = PermafrostRole(name="Bobs Super Group", site=self.site_2, category=self.role_category_1)
                role_b.save()

            with transaction.atomic():
                role_d = PermafrostRole(name="Bobs Super Group", site=self.site_2, category=self.role_category_2)
                role_d.save()

        # TODO: Add check to make sure PermafrostRole's Groups were not created


    # def test_clear_role_permissions(self):
    #     # Test that "included" permissions are always present in the group

    #     role = PermafrostRole(name="Bobs Staff Group", site=self.site_2, category=self.role_category_2)
    #     role.save()

        # print(len(role.permissions()))

        # self.assertEqual()

    #     Add Extra Permissions from the list
    #     run Clear method on role
    #     Make sure only the includes are present

    # Test the Client Users permissions

    # def test_django_admin_has_all_permissions(self):
    #     # Test the Django Users permissions
    #     raise NotImplementedError

    # Test that deleting a PermafrostRole deletes the matching group


#     def test_superuser_has_perms(self):
#         '''
#         Test that a user with
#         '''
#         View = self.get_view("any", ['edit-step', 'edit-path'])
#         request = self.get_request('/', self.superuser)

#         response = View.as_view()(request)
#         self.assertEqual(response.status_code, 200)


class PermafrostAPITest(TestCase):

    fixtures = ['unit_test']

    def setUp(self):
        User = get_user_model()
        self.user = User.objects.create_user(username='john', email='jlennon@beatles.com', password='Passw0rd!')
        self.staffuser = User.objects.create_user(username='staffy', email='staffy@beatles.com', password='Passw0rd!', is_active=True, is_staff=True, )
        self.adminuser = User.objects.create_user(username='adminy', email='adminy@beatles.com', password='Passw0rd!', is_active=True, is_staff=True, is_superuser=True)

        self.site_1 = Site.objects.get(pk=1)
        self.site_2 = Site.objects.get(pk=2)

        self.role_category_1 = PermafrostCategory.objects.get(pk=1)
        self.role_category_2 = PermafrostCategory.objects.get(pk=2)
        self.role_category_3 = PermafrostCategory.objects.get(pk=3)

        self.client = APIClient()

    def test_superuser_can_access_permissions_endpoint(self):
        '''
        Uses a user that has all the permissions.
        '''
        self.client.force_authenticate(user=self.adminuser)
        response = self.client.get('/permissions/', format='json')
        assert response.status_code == 200

    def test_can_not_access_permissions_endpoint(self):
        '''
        Uses a user that does not have the required permission
        '''
        self.client.force_authenticate(user=self.user)
        response = self.client.get('/permissions/', format='json')
        assert response.status_code == 403



from django.conf import settings
from django.contrib.sites.models import Site
from django.db import models
from django.contrib.auth.models import Group, Permission
from django.contrib.sites.shortcuts import get_current_site
from django.utils.translation import ugettext_lazy as _
from django.utils.text import slugify
from django.core.exceptions import ObjectDoesNotExist

from jsonfield import JSONField     # Using this instead of the PSQL one for portability


###############
# CHOICES
###############

# CATEGORIES = getAttr(settings, "PERMAFROST_CATEGORIES", {})
# CATEGORY_CHOICES = getAttr(settings, "PERMAFROST_CATEGORY_CHOICES", [])

###############
# UTILITIES
###############

def lable_from_choice_value(choices, value):
    return [x[1] for x in choices if x[0] == value][0]

def make_iterable(value):
    '''
    Takes whatever is passed in and tries to return it as a list
    '''
    if isinstance(value, list):
        return value

    if isinstance(value, models.query.QuerySet):
        return value

    if not value:
        return []

    return [value]

def get_permission_models(permissions):
    return [ permission_from_string(p) for p in make_iterable(permissions) ]

def permission_from_string(permission):
    values = permission.split(".")
    return Permission.objects.get(codename=values[1], content_type__app_label=values[0])

def get_current_site(*args, **kwargs):
    return settings.SITE_ID


###############
# MANAGERS
###############

class CategoryManager(models.Manager):
    def get_by_natural_key(self, slug):
        return self.get(slug=slug)


class PermafrostRoleManager(models.Manager):
    def get_by_natural_key(self, slug, site):
        return self.get(slug=slug, site=site)


###############
# MODELS
###############

class PermafrostCategory(models.Model):
    '''
    This holds the list of permissions that are available to be configured
    in the given category.  It contains both the "permissions", which are
    client configurable and the "includes" which are always included.

    TODO: Need to add localization support

    The permissions are kept in a JSON formatted list in the following structure:
    [
        {"perm":"permafrost.add_permafrostrole", "label":"Can add Permafrost Role"},
        {"perm":"permafrost.update_permafrostrole", "label":"Can update Permafrost Role"}
    ]

    They provide the ability to have a lables that are more human readable.

    The includes are kept in a JSON formatted list in the following structure:
    [
        "permafrost.view_permafrostrole",
        "permafrost.update_permafrostrole"
    ]

    As they are always present in a role of that Category Type, they don't 
    have a lable and are just a simple string list.

    Lists, rather than foreign keys, are used because there is no garuntee
    that a migration will not break the relationships.  Since this is rarely
    accessed, it is probably OK to take the DB hit to query this way.
    '''

    name = models.CharField(_("Name"), max_length=50)
    slug = models.SlugField(_("Slug"), blank=True, null=True)
    level = models.IntegerField(_("Security Level"), default=1)     # Scale 1-100, low to high security role category.
    permissions = JSONField(default=list, blank=True)
    includes = JSONField(default=list, blank=True)

    objects = CategoryManager()

    class Meta:
        verbose_name = _("Permafrost Category")
        verbose_name_plural = _("Permafrost Categories")

    def __str__(self):
        return self.name

    def natural_key(self):
        return (self.slug,)

    def save(self, *args, **kwargs):
        self.slug = slugify(self.name)
        result = super().save(*args, **kwargs)
        return result

    def get_include_models(self):
        return [ permission_from_string(permission) for permission in self.includes ]


class PermafrostRole(models.Model):
    '''
    PermafrostRole is Client Defineable and "manages" a Django Group adding a
    user to this role adds them to the Django Group and automatically assignes
    them the permissions.
    '''
    name = models.CharField(_("Name"), max_length=50)
    slug = models.SlugField(_("Slug"))
    # category = models.CharField(_("Category"), choices=CATEGORY_CHOICES)                                  # Should probably switch back to having configurable permissions be included in the code, better for consistency and security
    category = models.ForeignKey(PermafrostCategory, verbose_name=_("Category"), on_delete=models.CASCADE)
    site = models.ForeignKey(Site, on_delete=models.CASCADE, default=get_current_site)                      # This uses a callable so it will not trigger a migration with the projects it's included in
    locked = models.BooleanField(_("Locked"), default=False)                                                        # If this is locked, it can not be edited by the Client, used for System Default Roles
    deleted = models.BooleanField(_("Deleted"), default=False, help_text="Soft Delete the Role")
    group = models.ForeignKey(Group, verbose_name=_("Group"), on_delete=models.CASCADE, related_name="permafrost_role", blank=True, null=True)                  # NOTE: Need to make sure this is exported with natural key values as it can have a different PK on different servers

    objects = PermafrostRoleManager()

    class Meta:
        verbose_name = _("Permafrost Role")
        verbose_name_plural = _("Permafrost Roles")
        unique_together = [['name', 'site']]

        permissions = (
            ("add_user_to_role", "Can Add Users to Role"),
            ("add_user_to_administration", "Can Add Users to the Administration Roles"),
        )

    def __str__(self):
        return self.name

    def natural_key(self):
        return (self.slug, self.site)

    #-------------
    # Permissions

    def available(self):
        '''
        TODO!!!
        Based on the list of permissions in the Category, compile a list of all
        that are available.
        '''
        pass

    def conform_group(self):
        '''
        TODO!!!
        Based on the list of permissions in the Category, make sure the group
        has the right set.  Make sure no permissions are outside of the
        optional and required and that all required permissions are added.
        '''
        available = self.available()

    def group_name_schema(self, site, category, slug):
        return "{0}_{1}_{2}".format( site.pk, category.slug, slug)

    def get_group_name(self):
        return self.group_name_schema(self.site, self.category, self.slug)
    
    def permissions(self):
        return self.group.permissions

    def permissions_add(self, permissions):
        '''
        Add permissions to the attached group by name "app.perm"
        '''
        for p in get_permission_models(permissions):
            self.group.permissions.add(p)

    def permissions_remove(self, permissions):
        '''
        Remove permissions from the attached group by name "app.perm"
        '''
        for p in get_permission_models(permissions):
            self.group.permissions.remove(p)

    def permissions_set(self, permissions):
        '''
        This updates the group permissions to only include what was passed in by name "app.perm"
        '''
        self.group.permissions.set( get_permission_models(permissions) )

    def permissions_clear(self):
        '''
        Remove all permissions from the group except the defaults.
        '''
        if self.category.includes:
            self.group.permissions.set( self.category.includes )
        else:
            self.group.permissions.clear()

    #-------------
    # Users

    def user_set(self):
        '''
        Wrapper around the group that returns a queryset of all the user 
        included in this role.
        '''
        return self.group.user_set.all()


    def users_add(self, users=None):
        '''
        Pass in a User object to add to the PermafrostRole
        '''
        for user in make_iterable(users):
            user.groups.add(self.group)

    def users_remove(self, users=None):
        '''
        Pass in a User object to remove from the PermafrostRole
        '''
        for user in make_iterable(users):
            user.groups.remove(self.group)

    def users_clear(self):
        '''
        Remove all users from the PermafrostRole
        '''
        self.group.clear()

    #-------------
    # Save

    def save(self, *args, **kwargs):
        self.slug = slugify(self.name)
        group_name = self.get_group_name()

        if not self.pk:                                                             # if this is a new role, create the matching group
            self.group, created = Group.objects.get_or_create(name=group_name)      # Add the group if one named correctly alreay exists, otherwise create a new one.
        
        result = super().save(*args, **kwargs)

        if self.group.name != group_name:                                           # if the role is renamed after successful save, update the group's name
            self.group.name = group_name
            self.group.save()

        self.conform_group()                            # Apply after a successful save

        return result



from django.contrib import admin

from .models import PermafrostRole, PermafrostCategory

# ################
# # ADMIN ACTIONS
# ################

# def recreate_slug(modeladmin, request, queryset):
#     '''
#     This uses the save() instead of update() since the AutoSlugField is only generated on save().
#     '''
#     for item in queryset.all():
#         item.slug = ""
#         item.save()

# recreate_slug.short_description = "Regenerate the Slug Field"


# def make_enabled(modeladmin, request, queryset):
#     queryset.update(enabled=True)

# make_enabled.short_description = "Mark Enabled"


# def make_disabled(modeladmin, request, queryset):
#     queryset.update(enabled=False)

# make_disabled.short_description = "Mark Disabled"


def create_missing_groups(modeladmin, request, queryset):

    for item in queryset.all():
        # Make sure group exists and create if not after model is saved.
        item.get_group()


create_missing_groups.short_description = "Create a Django Group if missing"


###############
# MODEL ADMINS
###############

class PermafrostRoleAdmin(admin.ModelAdmin):
    readonly_fields = ('slug',)
    list_display = ('name', 'category', 'group', 'site')
    ordering = ('name',)
    readonly_fields=('slug',)
    actions = [create_missing_groups]

    # def get_readonly_fields(self, request, obj=None):
    #     if obj: # editing an existing object
    #         return self.readonly_fields + ('category',)
    #     return self.readonly_fields

    # def role_group(self, obj):
    #     if obj.group:
    #         return obj.group.name
    #     return None


class PermafrostCategoryAdmin(admin.ModelAdmin):
    readonly_fields = ('slug',)
    list_display = ('name',)
    ordering = ('name',)
    readonly_fields=('slug',)

###############
# REGISTRATION
###############

admin.site.register(PermafrostRole, PermafrostRoleAdmin)
admin.site.register(PermafrostCategory, PermafrostCategoryAdmin)



# Generated by Django 2.2.10 on 2020-02-18 22:34

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('auth', '0011_update_proxy_permissions'),
        ('permafrost', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='PermafrostRole',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=50, verbose_name='Name')),
                ('slug', models.SlugField(verbose_name='Slug')),
                ('category', models.IntegerField(choices=[(1, 'User'), (30, 'Staff'), (50, 'Administrator')], default=1, verbose_name='Permafrost Role Category')),
                ('locked', models.BooleanField(default=False, verbose_name='Locked')),
                ('group', models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='auth.Group', verbose_name='Group')),
                ('site', models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='sites.Site')),
            ],
            options={
                'verbose_name': 'Role',
                'verbose_name_plural': 'Roles',
                'unique_together': {('name', 'site')},
            },
        ),
        migrations.DeleteModel(
            name='Role',
        ),
    ]



# Generated by Django 3.0.3 on 2020-03-13 21:59

from django.db import migrations, models
import django.db.models.deletion
import permafrost.models


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('permafrost', '0005_auto_20200311_1701'),
    ]

    operations = [
        migrations.AlterField(
            model_name='permafrostrole',
            name='site',
            field=models.ForeignKey(default=permafrost.models.get_current_site, on_delete=django.db.models.deletion.CASCADE, to='sites.Site'),
        ),
    ]
